function [x,info] = bp_bregman(A,b,options)
% Solve using Bregman:
%
%    Minimize   ||x||_1   subject to    Ax = b
%
% References:
% * Wotao Yin, Stanley Osher, Donald Goldfarb, and Jerome Darbon
%   Bregman iterative algorithm for l1-minimization with applications
%   to compressed sensing

% September 29, 2009: Ewout van den Berg

% ---------------------------------------------------------------------
% Convert parameters
% ---------------------------------------------------------------------
if nargin < 5, options = struct(); end;

opts = l1_Bregman_opts;
if isfield(options,'verbosity') && options.verbosity > 0
   if options.verbosity == 1
      opts.disp = [1, 0, 0, 0, 0];
   else options.verbosity
      opts.disp = [1, 1, 1, 1, 1];
   end
else
   opts.disp = [0, 0, 0, 0, 0];
end

if isfield(options,'mu')
   mu = options.mu;
else
   mu = 0.02 / sqrt(size(A,1)*0.1); % Assume vector is (0.1*m)-sparse
end


% ---------------------------------------------------------------------
% Set default parameters explicitly
% ---------------------------------------------------------------------
op = spottify(A);

t0 = tic;
% =====================================================================
data = l1_Bregman(size(op,2), op, b, mu, [], opts);
x    = data.x;
% =====================================================================
info.time = toc(t0);

% ---------------------------------------------------------------------
% Gather statistics
% ---------------------------------------------------------------------
info.nA     = op.counter.mode1;
info.nAT    = op.counter.mode2;
info.nIter  = NaN;
info.r      = b - A*x;
info.rNorm  = norm(info.r,2);
info.xNorm  = norm(x,1);
info.lambda = 0;

