function [x,info] = bpdn_homotopy(A,b,sigma,lambdas,options)
% Solve using homotopy (as_topy.m):
%
%    Minimize   ||x||_1   subject to    ||Ax-b||_2 <= sigma
%
% The solver currently only takes lambda in
%
%    Minimize 0.5 ||Ax-b||_2^2 + lambda ||x||_1
%
% but because it already traverses all other values we simply give it
% the final value.

% August 18, 2009: Ewout van den Berg

% ---------------------------------------------------------------------
% Convert parameters
% ---------------------------------------------------------------------
if nargin < 5, options = struct(); end;
if isfield(options,'verbosity') && options.verbosity > 0
   opts.loglevel = 1;
else
   opts.loglevel = 0;
end
opts = as_setparms(opts);

if ~isreal(A) || ~isreal(b)
   error('bpdn_homotopy does not support complex data');
end

% ---------------------------------------------------------------------
% Solve problem
% ---------------------------------------------------------------------
nIter = 0;
op = spottify(A);

t0 = tic;
% =====================================================================
[x,data] = as_topy(op, b, lambdas(end), opts);
% =====================================================================
info.time = toc(t0);


% ---------------------------------------------------------------------
% Gather statistics
% ---------------------------------------------------------------------
info.nA     = op.counter.mode1;
info.nAT    = op.counter.mode2;
info.nIter  = nIter;
info.r      = b - A*x;
info.rNorm  = norm(info.r,2);
info.xNorm  = norm(x,1);
info.lambda = lambdas(end);

