function [x,info] = bpdn_spgl1(A,b,sigma,lambdas,options)
% Solve using SPGL1:
%
%    Minimize   ||x||_1   subject to    ||Ax-b||_2 <= sigma
%
% References:
% * Ewout van den Berg and Michael P. Friedlander
%   Probing the Pareto frontier for basis pursuit solutions
%   http://www.cs.ubc.ca/labs/scl/spgl1/

% August 17, 2009: Ewout van den Berg

% ---------------------------------------------------------------------
% Convert parameters
% ---------------------------------------------------------------------
if nargin < 5, options = struct(); end;
if ~isfield(options,'verbosity' ), options.verbosity  = 0;   end
if ~isfield(options,'maxRuntime'), options.maxRuntime = Inf; end;

op = spottify(A);

t0 = tic;
% =====================================================================
[x,r,g,data] = spgl1(op, b, 0, sigma, [], options);
% =====================================================================
info.time = toc(t0);

% ---------------------------------------------------------------------
% Gather statistics
% ---------------------------------------------------------------------
info.nA     = op.counter.mode1;
info.nAT    = op.counter.mode2;
info.nIter  = NaN;
info.r      = b - A*x;
info.rNorm  = norm(info.r,2);
info.xNorm  = norm(x,1);
info.lambda = norm(A'*info.r,inf);
info.lambdaHist = data.lambdaHist;

