function [X,info] = mmv_spgl1(A,B,sigma,lambdas,options)
% Solve using SPGL1:
%
%    Minimize   ||X||_1,2   subject to    ||AX-B||_F <= sigma
%
% References:
% * Ewout van den Berg and Michael P. Friedlander
%   Probing the Pareto frontier for basis pursuit solutions
%   http://www.cs.ubc.ca/labs/scl/spgl1/

% August 21, 2009: Ewout van den Berg

% ---------------------------------------------------------------------
% Convert parameters
% ---------------------------------------------------------------------
if nargin < 5, options = struct(); end;
if ~isfield(options,'verbosity')
   options.verbosity = 0; % No output by default.
end

% ---------------------------------------------------------------------
% Solve problem
% ---------------------------------------------------------------------
op = spottify(A);

t0 = tic;
% =====================================================================
[X,r,g,data] = spg_mmv(op, B, sigma, options);
% =====================================================================
info.time = toc(t0);

% ---------------------------------------------------------------------
% Gather statistics
% ---------------------------------------------------------------------
info.nA     = op.counter.mode1;
info.nAT    = op.counter.mode2;
info.nIter  = data.iter;
info.R      = B - A*X;
info.lambda = max(norms(A'*info.R,2,2));
info.RNorm  = norm(info.R,'fro');
info.XNorm  = sum(norms(X,2,2));


