function [X,info] = nucnorm_fpca(M,idx,sigma,lambdas,options)
% Solve using FPCA:
%
%    Minimize   ||X||_*   subject to    X(idx) = M(idx)
%
% References:
% * Shiqian Ma, Donald Goldfarb, and Lifeng Chen
%   Fixed point and Bregman iterative methods for matrix rank
%   minimization.
%   http://www.columbia.edu/~sm2756/FPCA.htm

% August 19, 2009: Ewout van den Berg

% ---------------------------------------------------------------------
% Initialize options structure
% ---------------------------------------------------------------------
[m,n] = size(M);
r     = min(m,n); % Assume full-rank
p     = length(idx) / (m*n);
maxr  = floor(((m+n)-sqrt((m+n)^2-4*length(idx)))/2);
fr    = r*(m+n-r)/length(idx);
opts  = get_opts_FPCA(M,maxr,m,n,p,fr);

if ~any(isnan(lambdas))
   opts.mu = lambdas(end);
end

% ---------------------------------------------------------------------
% Parse parameters
% ---------------------------------------------------------------------
if nargin < 5, options = struct(); end;

if isfield(options,'verbosity')
   if options.verbosity > 0
      opts.print = 1;
   else
      opts.print = 0;
   end
else
   opts.print = 0;
end

% ---------------------------------------------------------------------
% Solve problem
% ---------------------------------------------------------------------


try, t0 = toc; catch err, t0 = 0; tic; end;
% =====================================================================
data = FPCA_MatComp(m,n,idx,M(idx),opts);
% =====================================================================
info.time   = toc - t0;

% ---------------------------------------------------------------------
% Gather statistics
% ---------------------------------------------------------------------
X = data.x;
info.nIter  = data.iter;
info.nProj  = data.iter;
info.r      = X(idx) - M(idx);
info.xNorm  = norm_nuc(full(X));
info.rNorm  = norm(info.r,2);

