function [X,info] = nucnorm_spg(M,idx,sigma,lambdas,options)
% Solve using SPG:
%
%    Minimize   ||X||_*   subject to    ||X(idx) - M(idx)||_2 <= sigma
%
% References:
% * Ewout van den Berg and Michael P. Friedlander
%   Probing the Pareto frontier for basis pursuit solutions
%   http://www.cs.ubc.ca/labs/scl/spgl1/

% August 20, 2009: Ewout van den Berg

% ---------------------------------------------------------------------
% Convert parameters
% ---------------------------------------------------------------------
if nargin < 5, options = struct(); end;
if ~isfield(options,'verbosity')
   options.verbosity = 0; % No output by default.
end

% ---------------------------------------------------------------------
% Set up projection and norms
% ---------------------------------------------------------------------
[m,n] = size(M);
options.kappa       = @(x)     NormNuc_primal(m,n,x);
options.kappa_polar = @(x)     NormNuc_dual(m,n,x);
options.project     = @(x,tau) NormNuc_project(m,n,x,tau);
options.solver      = 1; % SPG

idx = idx(:);
op  = opRestriction(m*n,idx);

t0 = tic;
% =====================================================================
[X,data] = gbpdn(op,M(idx),[],sigma,[],options);
% =====================================================================
info.time = toc(t0);

% ---------------------------------------------------------------------
% Gather statistics
% ---------------------------------------------------------------------
X = reshape(X,m,n);
info.nA         = op.counter.mode1;
info.nAT        = op.counter.mode2;
info.nIter      = data.iter;
info.nProj      = data.nProjections;
info.r          = X(idx) - M(idx);
info.xNorm      = norm_nuc(full(X));
info.rNorm      = norm(info.r,2);
info.lambdaHist = data.lambdaHist;

