function [X,info] = nucnorm_spgl1(M,idx,sigma,lambdas,options)
% Solve using SPGL1:
%
%    Minimize   ||X||_*   subject to    ||X(idx) - M(idx)||_2 <= sigma
%
% References:
% * Ewout van den Berg and Michael P. Friedlander
%   Probing the Pareto frontier for basis pursuit solutions
%   http://www.cs.ubc.ca/labs/scl/spgl1/

% August 20, 2009: Ewout van den Berg

% ---------------------------------------------------------------------
% Convert parameters
% ---------------------------------------------------------------------
if nargin < 5, options = struct(); end;
if ~isfield(options,'verbosity')
   options.verbosity = 0; % No output by default.
end

% ---------------------------------------------------------------------
% Set up projection and norms
% ---------------------------------------------------------------------
[m,n] = size(M);
options.project     = @(x,weight,tau) NormNuc_project(m,n,x,tau);
options.primal_norm = @(x,weight)     NormNuc_primal(m,n,x);
options.dual_norm   = @(x,weight)     NormNuc_dual(m,n,x);

idx = idx(:);
op  = opRestriction(m*n,idx);

t0 = tic;
% =====================================================================
[X,r,g,data] = spgl1(op, M(idx), 0, sigma, [], options);
% =====================================================================
info.time = toc(t0);

% ---------------------------------------------------------------------
% Gather statistics
% ---------------------------------------------------------------------
X = reshape(X,m,n);
info.nA         = op.counter.mode1;
info.nAT        = op.counter.mode2;
info.nIter      = data.iter;
info.nProj      = data.nProjections;
info.r          = X(idx) - M(idx);
info.xNorm      = norm_nuc(full(X));
info.rNorm      = norm(info.r,2);
info.lambdaHist = data.lambdaHist;

