function [X,info] = nucnorm_svt(M,idx,sigma,lambdas,options)
% Solve using SVT:
%
%    Minimize   ||X||_*   subject to    X(idx) = M(idx)
%
% References:
% * Jian-Feng Cai, Emmanuel J. Candès and Zuowei Shen
%   A singular value thresholding algorithm for matrix completion
%   http://svt.caltech.edu/

% August 19, 2009: Ewout van den Berg

% ---------------------------------------------------------------------
% Initialize options structure
% ---------------------------------------------------------------------
[m,n] = size(M);
p     = length(idx) / (m*n);
opts         = struct();
opts.delta   = 1.2 / p; % 0.01;
opts.tau     = 5 * sqrt(m*n);
opts.maxiter =500;
opts.tol     = 1e-4;

% ---------------------------------------------------------------------
% Parse parameters
% ---------------------------------------------------------------------
if nargin < 5, options = struct(); end;

% ---------------------------------------------------------------------
% Solve problem
% ---------------------------------------------------------------------

t0 = tic;
% =============================================================================
[U,S,V,iter] = SVT([m,n],idx,M(idx),opts.tau,opts.delta,opts.maxiter,opts.tol);
% =============================================================================
info.time = toc(t0);

% ---------------------------------------------------------------------
% Gather statistics
% ---------------------------------------------------------------------
X = U*S*V';
info.nIter = iter;
info.nProj = iter;
info.r     = X(idx) - M(idx);
info.xNorm = norm(diag(S),1);
info.rNorm = norm(info.r,2);

