function [x,info,status] = solution_bpdn_runtime(problem, solverCell, options)
%
% status:
%    'internal error'   Solver to obtain lambda requires lambda
%    'n.a.'             Solver cannot handle problem
%    'no lambda'        Value of lambda was required but not available
%    'error'            An error occurred while running the solver
%    'timeout'          Time limit reached
%    'ok'               All is well!

% Initialize output
x      = [];
info   = [];
status = '';

% Extract solver properties
solver = struct();
solver.name        = solverCell{1};
solver.funHandle   = solverCell{2};
solver.explicit    = solverCell{3};
solver.orthonormal = solverCell{4};
solver.lambda      = solverCell{5};
solver.complex     = solverCell{6};
solver.nmax        = solverCell{7};
explicit           = false;

% Check solver options
if nargin < 3, options = struct(); end;
options.maxRuntime = 1800;

% Check if solver can be used
if ~problem.ortho && solver.orthonormal
   status = 'n.a.'; return;
end
if problem.oper
   if islogical(solver.explicit)
      if solver.explicit == true
         status = 'n.a.'; return;
      end
   else
      if prod(size(problem.A)) > solver.explicit
         status = 'n.a.'; return;
      else
         explicit = true;
      end
   end
end
if ~solver.complex && (~isreal(problem.A) || ~isreal(problem.b))
   status = 'n.a.'; return; 
end
if size(problem.A,2) > solver.nmax
   status = 'n.a.'; return; 
end

% Construct filename for cache
prefix      = mfilepath(mfilename('fullpath'));
prefixCache = [prefix, 'cache', filesep];
filename    = [prefixCache, sprintf('solution_bpdn_1800_%s_%s.mat',lower(problem.name),lower(solver.name))];

% Return immediately if cached result exists
if exist(filename)
   data   = load(filename);
   x      = data.x;
   info   = data.info;
   status = data.status;
   return;
end

% Call solver
try
   if problem.oper && explicit
      problem.A = double(problem.A);
   end

   [x,info] = solver.funHandle(problem.A, problem.b, problem.sigma, problem.lambdas(end), options);
   status = 'ok';
catch err
   x      = [];
   info   = err;
   status = 'error';
end

% Store result (even in case of runtime error)
save(filename,'x','info','status');

