function [X,info,status] = solution_mmv(problem, solverCell, options)
%
%  Solvers should already include options.
%
% status:
%    'internal error'   Solver to obtain lambda requires lambda
%    'n.a.'             Solver cannot handle problem
%    'no lambda'        Value of lambda was required but not available
%    'error'            An error occurred while running the solver
%    'timeout'          Time limit reached
%    'ok'               All is well!

% Initialize output
X      = [];
info   = [];
status = '';

% Extract solver properties
solver = struct();
solver.name        = solverCell{1};
solver.funHandle   = solverCell{2};
solver.explicit    = solverCell{3};
solver.lambda      = solverCell{4};

% Check solver options
if nargin < 3, options = struct(); end;

% Check if solver can be used
if problem.oper && solver.explicit
   status = 'n.a.'; return;
end

% Construct filename for cache
prefix      = mfilepath(mfilename('fullpath'));
prefixCache = [prefix, 'cache', filesep];
filename    = [prefixCache, sprintf('solution_mmv_%s_%s.mat',lower(problem.name),lower(solver.name))];

% Return immediately if cached result exists
if exist(filename)
   data   = load(filename);
   X      = data.X;
   info   = data.info;
   status = data.status;
   return;
end

% Call solver
try
   [X,info] = solver.funHandle(problem.A, problem.B, problem.sigma, problem.lambdas(end), options);
   status = 'ok';
catch err
err
   X      = [];
   info   = [];
   status = 'error';
end

% Store result (even in case of runtime error)
save(filename,'X','info','status');

