function [solvers] = solvers_bp
% SOLVERS_BP   Returns a cell array of solvers.
%
%    [SOLVERS] = SOLVERS_BP returns a cell array SOLVERS with one solver
%    per row. Each column contains the following entries
%      * Solver name
%      * Function handle (A,b,options)
%      * Explicit flag, set when method requires explicit matrix, when set
%        to a number it indicates the maximum size of implicit matrices that
%        are allowed to be converted to explicit matrices.
%      * Orthonormal flag, set when method requires orthonormal matrices
%      * Complex flag, set when method support complex coefficients
%      * Nmax, maximum length of vector x.
%
%    The variable SOLVERIDXLAMBDA gives the index of the solver used to
%    obtain the mapping from sigma to a series of lambda values to emulate
%    root finding in the penalized formulation.

% September 29, 2009: Ewout van den Berg

% ---------------------------------------------------------------------------------------
%                                          R e q u i r e m e n t s
%          Solver      Function       Explicit   Orthonormal   Complex  Nmax
% ---------------------------------------------------------------------------------------
solvers = {'CVX',      @bp_cvx,       2.1e6,     false,        true,    3e3; ...
           'Nesta',    @bp_nesta,     false,     true,         false,   Inf; ...
%          'BPDQ',     @bp_bpdq,      false,     false,        false,   Inf; ...
           'SPGL1',    @bp_spgl1,     false,     false,        true,    Inf; ...
           'PQN',      @bp_pqn,       false,     false,        true,    Inf; ...
           'SPG',      @bp_spg,       false,     false,        true,    Inf; ...
           'Homotopy', @bp_homotopy,  false,     false,        false,   1e4; ... % 1e4!!!
           'Bregman',  @bp_bregman,   false,     false,        false,   Inf};

