function solvers = solvers_bpdn2
% SOLVERS_BPDN2   Returns a cell array of solvers.
%
%    SOLVERS = SOLVERS_BPDN2 returns a cell array SOLVERS with one solver
%    per row. Each column contains the following entries
%      * Solver name
%      * Function handle (A,b,sigma,lambdas,options)
%      * Explicit flag, set when method requires explicit matrix, when set
%        to a number it indicates the maximum size of implicit matrices that
%        are allowed to be converted to explicit matrices.
%      * Orthonormal flag, set when method requires orthonormal matrices
%      * Complex flag, set when method support complex coefficients
%      * Lambda flag, set when method works with penalized formulation.
%      * Nmax, maximum length of vector x.

% October 1, 2009: Ewout van den Berg

% ---------------------------------------------------------------------------------------
%                                          R e q u i r e m e n t s
%          Solver      Function       Explicit   Orthonormal   Lambda   Complex  Nmax
% ---------------------------------------------------------------------------------------
solvers = {'CVX',      @bpdn_cvx,     2.1e6,     false,        false,   true,    3e3; ...
           'Nesta',    @bpdn_nesta,   false,     true,         false,   true,    Inf; ...
%          'BPDQ',     @bpdn_bpdq,    false,     false,        false,   false,   Inf; ...
           'SPGL1',    @bpdn_spgl1,   false,     false,        false,   true,    Inf; ...
           'PQN',      @bpdn_pqn,     false,     false,        false,   true,    Inf; ...
           'SPG',      @bpdn_spg,     false,     false,        false,   true,    Inf; ...
           'Homotopy', @bpdn_homotopy,false,     false,        true,    false,   1e4; ...
           'GPSR',     @bpdn_gpsr,    false,     false,        true,    false,   Inf; ...
           'L1LS',     @bpdn_l1ls,    2.1e6,     false,        true,    false,   3e3; ...
           'FPC',      @bpdn_fpc,     false,     false,        true,    false,   Inf; ...
           'Fista',    @bpdn_fista,   false,     false,        true,    true,    Inf};

