function table_bp_dct2(latexFlag,outputFlag)

% Check arguments
if nargin < 1, latexFlag = false; end;
if nargin < 2, outputFlag = false; end;

% Get path information
prefix      = mfilepath(mfilename('fullpath'));
prefixTable = [prefix,'..',filesep,'..',filesep,'fig',filesep];


problems  = {'orthimpl2a','orthimpl2b','orthimpl2c','orthimpl2d','orthimpl2g','orthimpl2j'};
problemN  = [10,11,12,13,16,19];
solvers   = solvers_bp();
solverIdx = [1,2,3,5,4,6,7];

if latexFlag
   solverName = {'\cvxsdp','\nesta','\spg','\spgt','\pqn','Homotopy','Bregman'};
   titleStr   = 'Sparsity = $2^{n-4}$';
else
   solverName = {'CVX/SDPT3','Nesta','SPOR-SPG-H','SPOR-SPG','SPOR-PQN','Homotopy','Bregman'};
   titleStr   = 'Sparsity = 2^{n-4}';
end

if outputFlag
   filename = [prefixTable,'TableBP_DCT2.tex'];
   fp = fopen(filename,'w');
   if fp == -1, error('Could not open output file %s\n', filename); end;
else
   fp = 1;
end

% Output header
if latexFlag
   fieldWidth = 7;
   fprintf(fp,'\\begin{tabular}{l%s}\n',repmat('c',1,length(problems)));
   fprintf(fp,'\\toprule\n',length(problems)+1);
   fprintf(fp,'\\multicolumn{1}{l}{} & \\multicolumn{%d}{c}{%s} \\\\\n',length(problems),titleStr);
   fprintf(fp,'\\midrule\n');
   fprintf(fp,'Solver ');
   for i=1:length(problems)
      fprintf(fp,'& $n=%d$ ', problemN(i));
   end
   fprintf(fp,'\\\\\n');
else
   fieldWidth = 6;
   fprintf(fp,'%s\n',repmat('=',1,12+length(problems)*(fieldWidth+3)));
   fprintf('Title: %s\n', titleStr);
   fprintf('%-10s  ', 'Solver');
   for i=1:length(problems)
      str = sprintf('n=%d', problemN(i));
      fprintf(' %*s ',-fieldWidth,str);
   end
   fprintf('\n');
   fprintf(fp,'%s\n',repmat('=',1,12+length(problems)*(fieldWidth+3)));
end

% Run all problems
problemInfo = {};
for i=1:length(problems)
   problemName = problems{i};
   problem = problem_bp(problemName);

   % Run all solvers first
   solverInfo = {};
   for j=1:length(solverIdx)
      [x,info,status] = solution_bp(problem,solvers(solverIdx(j),:));

      if strcmp(status,'ok')
         strTime = sprintf('%6.1e', info.time);
         if isnan(info.nA+info.nAT)
            strAprod = 'n.a.';
         else
            strAprod = sprintf('%d',info.nA+info.nAT);
         end
      else
         strTime  = '---';
         strAprod = '---';
      end

      solverInfo{end+1} = strTime;
      solverInfo{end+1} = strAprod;
   end
   % Format output
   [solverInfo,widths] = formatTableData({solverInfo},latexFlag);
   solverInfo = solverInfo{1};

   % Add information
   problemInfo{end+1} = solverInfo;
end

% Output table body
for i=1:length(solverIdx)
   if latexFlag
      fprintf(fp,'\\midrule\n');
      fprintf(fp,'\\multirow{2}{*}{%s}\n',solverName{i});
      for j=1:length(problems)
         info     = problemInfo{j};
         strTime  = info{2*i-1};
         fprintf(fp,' & %*s',-fieldWidth,strTime);
      end
      fprintf(fp,' \\\\\n');
      for j=1:length(problems)
         info     = problemInfo{j};
         strAprod  = info{2*i};
         fprintf(fp,' & %*s',-fieldWidth,strAprod);
      end
      fprintf(fp,' \\\\\n');
   else
      fprintf(fp,'%-10s  ', solverName{i});
      for j=1:length(problems)
         info     = problemInfo{j};
         strTime  = info{2*i-1};
         fprintf(fp,'| %*s ',-fieldWidth,strTime);
      end
      fprintf(fp,'\n');
      fprintf(fp,'%-10s  ', '');
      for j=1:length(problems)
         info     = problemInfo{j};
         strAprod  = info{2*i};
         fprintf(fp,'| %*s ',-fieldWidth,strAprod);
      end
      fprintf('\n');
   end
end

% Output table footer
if latexFlag
   fprintf(fp,'\\bottomrule\n');
   fprintf(fp,'\\end{tabular}\n');
end

% Close file
if outputFlag
   fclose(fp);
end

