function table_bpdn_problems(latexFlag,outputFlag)

% Check arguments
if nargin < 1, latexFlag = false; end;
if nargin < 2, outputFlag = false; end;

% Get path information
prefix      = mfilepath(mfilename('fullpath'));
prefixTable = [prefix,'..',filesep,'..',filesep,'fig',filesep];


problems  = {'srcsep1','seismic','phantom2','finger'};

% Open file
if outputFlag
   filename = [prefixTable,'TableBPDN_Problems.tex'];
   fp = fopen(filename,'w');
   if fp == -1, error('Could not open output file %s\n', filename); end;
else
   fp = 1;
end

% Output header
if latexFlag
   fprintf(fp,'\\begin{tabular}{lccc}\n');
   fprintf(fp,'\\toprule\n');
   fprintf(fp,' & \\multicolumn{3}{c}{$\\mu$\\ \\ ($\\norm{x^*}_1$)} \\\\\n');
%   fprintf(fp,'\\cline{2-4}\n');
   fprintf(fp,'Problem & $\\sigma = 0.1\\norm{b}_2$ & $\\sigma = 0.01\\norm{b}_2$ & $\\sigma = 0.001\\norm{b}_2$ \\\\\n');
   fprintf(fp,'\\midrule\n');
else
   fprintf(fp,'%s\n',repmat('=',1,78));
   fprintf(fp,'Entries: mu (norm(x,1))\n');
   fprintf(fp,'%-10s  %-21s  %-21s  %-21s\n','Problem','sigma = 0.1||b||','sigma = 0.01||b||','sigma = 0.001||b||');
   fprintf(fp,'%s\n',repmat('=',1,78));
end

% Output table body
for i=1:length(problems)
   % Output problem header
   if latexFlag
      fprintf(fp,'%-10s',problems{i});
   else
      fprintf(fp,'%-10s  ',problems{i});
   end

   for j=1:3
      p = problem_bpdn2(sprintf('%s_s%d',problems{i},j));
      if p.accuracy < 1e-9
         info = {{sprintf('%6.0e',p.accuracy),sprintf('%9.4e',norm(p.x,1))}};
      else
         info = {{sprintf('%6.1e',p.accuracy),sprintf('%9.4e',norm(p.x,1))}};
      end
      info = formatTableData(info,latexFlag);
      info = info{1};
      if latexFlag
         fprintf(fp,' & %-8s (%s)', info{1},info{2});
      else
         str = sprintf('%-7s (%s)', info{1},info{2});
         fprintf(fp,'%-21s  ',str);
      end
   end

   if latexFlag
      fprintf(fp,'\\\\\n');
   else
      fprintf(fp,'\n');
   end
end

% Output table footer
if latexFlag
   fprintf(fp,'\\bottomrule\n');
   fprintf(fp,'\\end{tabular}\n');
end

% Close file
if outputFlag
   fclose(fp);
end

