function table_bpdn_sparcoS1(latexFlag,outputFlag)

% Check arguments
if nargin < 1, latexFlag = false; end;
if nargin < 2, outputFlag = false; end;

% Get path information
prefix      = mfilepath(mfilename('fullpath'));
prefixTable = [prefix,'..',filesep,'..',filesep,'fig',filesep];


problems = {'srcsep1','seismic','phantom2','finger'};
postfix  = '_s1';
solvers   = solvers_bpdn2();
solverIdx = [3,5,4,NaN,7,9,10];

if latexFlag
   solverName = {'\spg','\spgt','\pqn',NaN,'\gpsr','\fpc','\fista'};
else
   solverName = {'SPOR-SPG-H','SPOR-SPG','SPOR-PQN',NaN,'GPSR','FPC','FISTA'};
end

if outputFlag
   filename = [prefixTable,'TableBPDN_SparcoS1.tex'];
   fp = fopen(filename,'w');
   if fp == -1, error('Could not open output file %s\n', filename); end;
else
   fp = 1;
end

% Output header
if latexFlag
   fprintf(fp,'\\begin{tabular}{lllrcc}\n');
   fprintf(fp,'\\toprule\n');
   fprintf(fp,'\\multicolumn{1}{l}{} & Solver & Time (s) & Aprod & $\\norm{x}_1$ & $\\norm{x - x^*}_\\infty$ \\\\\n');
else
   formatStr = '%-10s  %-8s  %8s  %-9s  %-9s\n';
   headerFld = {'Solver','Time(s)','Aprod','norm(x,1)','||x-x0||'};
   headerStr = sprintf(formatStr, headerFld{:});
   fprintf(fp,'%s\n',repmat('=',1,length(headerStr)));
   fprintf(fp,'%s',headerStr);
   fprintf(fp,'%s\n',repmat('=',1,length(headerStr)));
end

for i=1:length(problems)
   problemInfo = {};
   problemName = problems{i};
   problem     = problem_bpdn2([problemName,postfix]);

   for j=1:length(solverIdx)
      if isnan(solverIdx(j))
         % Add code for inserting separator
         data = {'','','','',''};
         problemInfo{end+1} = data;
         continue;
      end

      % Get results
      [x,info,status] = solution_bpdn2(problem,solvers(solverIdx(j),:));
      if ~strcmp(status,'ok'), continue; end;

      % Format and append results
      strTime  = sprintf('%6.1e',info.time);
      strAprod = sprintf('%d',   info.nA + info.nAT);
      strXNorm = sprintf('%9.4e',norm(x,1));
      strDNorm = sprintf('%6.1e',norm(x-problem.x,inf));
      data = {solverName{j},strTime,strAprod,strXNorm,strDNorm};
      problemInfo{end+1} = data;
   end

   % Format output data
   [problemInfo,widths] = formatTableData(problemInfo,latexFlag);

   % Count number of separator fields
   nSeps = 0;
   for j=1:length(problemInfo)
      data = problemInfo{j};
      if isempty(data{1}), nSeps = nSeps + 1; end;
   end

   % Output problem header
   if latexFlag
      fprintf(fp,'\\midrule\n');
      fprintf(fp,'\\multirow{%d}{*}{\\rotatebox{90}{\\small %s}}\n', length(problemInfo)-nSeps, problemName);
   else
      fprintf(fp,'%s[%s]%s\n',repmat('-',1,3),problemName,repmat('-',1,max(0,length(headerStr)-5-length(problemName))));
   end

   % Output problem data
   for j=1:length(problemInfo)
      data = problemInfo{j};
      if isempty(data{1})
         if latexFlag
%            fprintf(fp,'\\cline{3-6}\n');
         end
      else
         if latexFlag
            fprintf(fp,'&%*s & %*s & %*s & %*s & %*s \\\\\n', ...
                    -widths(1), data{1}, -widths(2), data{2}, widths(3), data{3}, ...
                    -widths(4), data{4}, -widths(5), data{5});
         else
            fprintf(fp,formatStr,data{:});
         end
      end
   end
end


% Output table footer
if latexFlag
   fprintf(fp,'\\bottomrule\n');
   fprintf(fp,'\\end{tabular}\n');
end

% Close file
if outputFlag
   fclose(fp);
end

