function GenerateTable(tableidx,exportFlag)
% GENERATETABLE   Generates table from the paper
%
%    GENERATETABLE(TABLEIDX,EXPORTFLAG) generates table TABLEIDX from the
%    paper, if it exists. The optional EXPORTFLAG parameter can be set to
%    export the table to a LaTeX file. When TABLEIDX = [], all tables are
%    generated.

% Create list of tables
tableidc = {'7.2',...
            '8.2','8.3',...
            'A.2','A.3','A.4','A.5','A.6','A.7','A.8','A.10'};

% Check parameters
if nargin < 1
   error('First parameter should be a table index string, e.g. ''%s''', tableidc{1});
end
if nargin < 2
   exportFlag = 0;
end

% Generate all tables if tableidx is empty
if isempty(tableidx)
   for i=1:length(tableidc)
      GenerateTable(tableidc{i},exportFlag);
   end

   return;
end

% Generate specified table
switch tableidx

% ---------------------------------------------------------------------
% Chapter 7 - Sign-constrained basis pursuit
% ---------------------------------------------------------------------

case {'7.1',7.1}
   fprintf('This table was generated manually.\n');

case {'7.2',7.2}
    ExecuteScript('Experiments','table_nonneg(exportFlag,exportFlag);');


% ---------------------------------------------------------------------
% Chapter 8 - Matrix completion
% ---------------------------------------------------------------------

case {'8.1',8.1}
   fprintf('This table was generated manually.\n');

case {'8.2',8.2}
    ExecuteScript('Experiments','table_nucnorm_noiseless(exportFlag,exportFlag);');

case {'8.3',8.3}
    ExecuteScript('Experiments','table_nucnorm_noisy(exportFlag,exportFlag);');


% ---------------------------------------------------------------------
% Appendix
% ---------------------------------------------------------------------

case {'A1','A.1','1',1}
   fprintf('This table was generated manually.\n');

case {'A2','A.2','2',2}
   ExecuteScript('Experiments','table_bp(exportFlag,exportFlag);');
 
case {'A3','A.3','3',3}
   ExecuteScript('Experiments','table_bp_gaussian(exportFlag,exportFlag);');

case {'A4','A.4','4',4}
   ExecuteScript('Experiments','table_bp_dct1(exportFlag,exportFlag);');
   ExecuteScript('Experiments','table_bp_dct2(exportFlag,exportFlag);');

case {'A5','A.5','5',5}
   if ~HaveCurvelab('Table A.5'), return; end;
   ExecuteScript('Experiments','table_bpdn_problems(exportFlag,exportFlag);');

case {'A6','A.6','6',6}
   if ~HaveCurvelab('Table A.6'), return; end;
   ExecuteScript('Experiments','table_bpdn_sparcoS1(exportFlag,exportFlag);');

case {'A7','A.7','7',7}
   if ~HaveCurvelab('Table A.7'), return; end;
   ExecuteScript('Experiments','table_bpdn_sparcoS3(exportFlag,exportFlag);');

case {'A8','A.8','8',8}
   ExecuteScript('Experiments','table_bpdn_compress(exportFlag,exportFlag);');

case {'A9','A.9','9',9}
   fprintf('This table was generated manually.\n');

case {'A10','A.10','10',10}
   ExecuteScript('Experiments','table_mmv(exportFlag,exportFlag);');

case {'A11','A.11','11',11}
   GenerateTable('7.1',exportFlag);

case {'A12','A.12','12',12}
   GenerateTable('7.2',exportFlag);

case {'A13','A.13','13',13}
   GenerateTable('8.1',exportFlag);

case {'A14','A.14','14',14}
   GenerateTable('8.2',exportFlag);

case {'A15','A.15','15',15}
   GenerateTable('8.3',exportFlag);

otherwise
   if ischar(tableidx)
      fprintf('No code available to generate Table %s\n',tableidx);
   else
      fprintf('No code available to generate Table %d\n',tableidx);
   end
end


% Execude script in its local directory
function ExecuteScript(workdir,command)

   p = pwd;
   cd([mfilepath(mfilename('fullpath')),workdir]);
   try
      eval(command);
      cd(p);
   catch exception
      cd(p);
      rethrow(exception);
   end
end

function pauseMessage(exportFlag)
   if ~exportFlag
      fprintf('Press <return> to continue . . .\n');
      pause;
   end
end

function result = HaveCurvelab(msg)
   str = which('fdct_wrapping');
   result = ~isempty(str);
   if ~result
      fprintf('%s cannot be generated without Curvelab.\n',msg);
   end
end

end

